import serial
import requests
import time
import os

from dotenv import load_dotenv

load_dotenv()


api_url = os.getenv('API_URL')
calculer_consommation =  api_url + '/calculer-volume-consumption'
methode_notification_url = api_url + '/methode-notification'

temps_recuperation_method_notification = os.getenv('TEMPS_RECUPERATION_METHOD_NOTIFICATION') # en secondes
temps_recuperation_distance = os.getenv('TEMPS_RECUPERATION_DISTANCE') # en secondes

arduino_port = '/dev/ttyACM0'
ser = serial.Serial(arduino_port, 9600, timeout=1)

try:
    while True:
        # Récupérer la méthode de notification actuelle toutes les 20 minutes
        if time.time() % 1200 == 0:
            try:
                notification_response = requests.get(methode_notification_url)
                notification_response.raise_for_status()
                notification_method = notification_response.json().get('methodeNotification', 'sound')
            except requests.exceptions.RequestException as e:
                print(f"Erreur lors de la récupération de la méthode de notification : {e}")
                notification_method = 'sound'

        # Récupérer la distance toutes les 5 minutes
        if time.time() % 300 == 0:
            line = ser.readline().decode('utf-8').rstrip()
            # print(f"Arduino dit : {line}")

            if 'Distance' in line:
                distance = float(line.split(':')[-1].strip().split(' ')[0])
                print(f"Distance : {distance} cm")

                payload = {'distance': distance}
                try:
                    response = requests.post(calculer_consommation, json=payload)
                    response.raise_for_status()
                    data = response.json()
                    print(f"API Response: {data}")
                except requests.exceptions.RequestException as e:
                    print(f"Erreur lors de l'appel API : {e}")

        time.sleep(1)

except KeyboardInterrupt:
    ser.close()
    print("Arrêt du programme.")
